@@ -85,6 +85,9 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                     case 'upload':
                         this._addUploadButton(cfg,btCfg,getFormData);
                         break;
+                    case 'separator':
+                        this.add(new qx.ui.core.Spacer(10,10));
+                        break;
                     default:
                         this.debug('Invalid execute action:' + btCfg.action);
                 }
